@@ -14,7 +14,6 @@
 
 mod config;
 pub mod file_locations;
-mod type_config;
 
 use std::{
     collections::hash_map::DefaultHasher,
@@ -30,8 +29,6 @@ use syn::{
     Macro,
 };
 
-pub use type_config::TypeConfig;
-
 /// Core of the autocxx engine. See `generate` for most details
 /// on how this works.
 pub struct IncludeCpp {
